# django-payex

django-payex is a Django application for saving statuses and receiving 
callbacks from the PayEx API. 

Check out the [pypayex](https://github.com/funkbit/pypayex) module for 
communication with the PayEx API. The callback view and agreement verification 
check requires the `payex` module.

The PayEx implementation manual is available here:
http://www.payexpim.com/

## Status

This is a work in progress, patches are welcome :)
